@@ -61,6 +61,26 @@ class ClientTests(ZookeeperTestCase):
         self.failUnlessFailure(d, ConnectionTimeoutException)
         return d
 
+    def test_wb_reconnect_after_timeout_and_close(self):
+        """
+        Another odd error scenario, if a client instance has has
+        connect and closed methods invoked in succession multiple
+        times, and a previous callback connect timeouts, the callback
+        of a previous connect can be invoked by a subsequent connect,
+        with a CONNECTING_STATE. Verify this does not attempt to
+        invoke the connect deferred again.
+        """
+        d = Deferred()
+        d.callback(True)
+
+        task = DelayedCall(1, lambda: 1, None, None, None, None)
+        task.called = True
+
+        self.assertEqual(
+            self.client._cb_connected(
+                task, d, None, zookeeper.CONNECTING_STATE, ""),
+            None)
+
     def test_connect(self):
         """
         The client can connect to a zookeeper instance.
@@ -486,7 +506,7 @@ class ClientTests(ZookeeperTestCase):
 
         def create_seq_node(path):
             return self.client.create(
-                "/seq-a/seq-", flags=zookeeper.EPHEMERAL|zookeeper.SEQUENCE)
+                "/seq-a/seq-", flags=zookeeper.EPHEMERAL | zookeeper.SEQUENCE)
 
         def get_children(path):
             return self.client.get_children("/seq-a")
@@ -660,7 +680,6 @@ class ClientTests(ZookeeperTestCase):
             return watch_deferred
 
         def verify_observed(data):
-            import pdb; pdb.set_trace()
             self.assertTrue(data)
 
         d.addCallback(create_node)
